@@ -2,7 +2,6 @@
 from django.db import models
 from django.core.exceptions import ImproperlyConfigured
 from django.conf import settings
-from django.utils.translation import ugettext as _
 from datetime import datetime
 from vkontakte_api.utils import api_call, VkontakteError
 from vkontakte_api import fields
@@ -47,6 +46,7 @@ class UsersManager(models.Manager):
 class UsersRemoteManager(VkontakteManager):
 
     def fetch(self, **kwargs):
+        # TODO: remove here restriction to fetch no more then 1000 users per time
         if 'only_expired' in kwargs and kwargs.pop('only_expired'):
             ids = kwargs['ids']
             ids_actual = list(self.model.objects.filter(fetched__gte=datetime.now()-timedelta(VKONTAKTE_USERS_INFO_TIMEOUT_DAYS), remote_id__in=ids).values_list('remote_id', flat=True))
@@ -129,9 +129,8 @@ class User(VkontakteIDModel):
     TODO: implement relatives, schools and universities connections
     '''
     class Meta:
-        db_table = 'vkontakte_users_user'
-        verbose_name = _('Vkontakte user')
-        verbose_name_plural = _('Vkontakte users')
+        verbose_name = u'Пользователь Вконтакте'
+        verbose_name_plural = u'Пользователи Вконтакте'
         ordering = ['remote_id']
 
     remote_pk_field = 'uid'
@@ -291,13 +290,19 @@ class User(VkontakteIDModel):
     def __unicode__(self):
         return self.first_name + ' ' + self.last_name
 
+    def set_name(self, name):
+        name_parts = name.split()
+        self.first_name = name_parts[0]
+        if len(name_parts) > 1:
+            self.last_name = ' '.join(name_parts[1:])
+
     def fetch_posts(self, *args, **kwargs):
-        if 'vkontakte_wall' in settings.INSTALLED_APPS:
-            from vkontakte_wall.models import Post
-            return Post.remote.fetch_user_wall(user=self, *args, **kwargs)
-        else:
+        if 'vkontakte_wall' not in settings.INSTALLED_APPS:
             raise ImproperlyConfigured("Application 'vkontakte_wall' not in INSTALLED_APPS")
 
+        from vkontakte_wall.models import Post
+        return Post.remote.fetch_user_wall(user=self, *args, **kwargs)
+
     def fetch_friends(self):
         if self.is_deactivated:
             return False
@@ -334,8 +339,7 @@ class User(VkontakteIDModel):
 #    TODO: Solve naming, dublicate with boolean wall_comments
 #    @property
 #    def wall_comments(self):
-#        if 'vkontakte_wall' in settings.INSTALLED_APPS:
-#            from vkontakte_wall.models import Comment
-#            return Comment.objects.filter(remote_id__startswith='%s_' % self.remote_id)
-#        else:
-#            raise ImproperlyConfigured("Application 'vkontakte_wall' not in INSTALLED_APPS")
\ No newline at end of file
+#        if 'vkontakte_wall' not in settings.INSTALLED_APPS:
+#            raise ImproperlyConfigured("Application 'vkontakte_wall' not in INSTALLED_APPS")
+#        from vkontakte_wall.models import Comment
+#        return Comment.objects.filter(remote_id__startswith='%s_' % self.remote_id)
\ No newline at end of file
